package com.clx.performance.controller.pc.owner;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.clx.performance.param.pc.*;
import com.clx.performance.service.OwnerAccountService;
import com.clx.performance.service.OwnerCaseOutService;
import com.clx.performance.service.OwnerRunningWaterRecordService;
import com.clx.performance.service.OwnerTopUpService;
import com.clx.performance.vo.pc.OwnerAccountRunningWaterRecordVO;
import com.clx.performance.vo.pc.OwnerAccountVO;
import com.clx.performance.vo.pc.OwnerCaseOutVO;
import com.clx.performance.vo.pc.OwnerTopUpVO;
import com.msl.common.base.PageData;
import com.msl.common.convertor.aspect.UnitCovert;
import com.msl.common.result.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Slf4j
@RestController
@RequestMapping("/pc/owner")
@Validated
@AllArgsConstructor
@Api(tags = "PC-资金管理")
public class OwnerAccountController {

    private final OwnerAccountService ownerAccountService;

    private final OwnerTopUpService ownerTopUpService;

    private final OwnerCaseOutService ownerCaseOutService;

    private final OwnerRunningWaterRecordService ownerRunningWaterRecordService;

    @ApiOperation(value = "账户信息", notes = "<br>By:胡宇帆")
    @GetMapping("/accountInfo")
    @UnitCovert(param = false)
    public Result<List<OwnerAccountVO>> accountInfo(@RequestParam String ownerNo) {
        List<OwnerAccountVO> accountVOList = ownerAccountService.accountInfo(ownerNo);
        return Result.ok(accountVOList);
    }

    @ApiOperation(value = "货主充值记录列表", notes = "<br>By:胡宇帆")
    @PostMapping("/ownerTopUpPageList")
    @UnitCovert(param = false)
    public Result<PageData<OwnerTopUpVO>> ownerTopUpPageList(@RequestBody PageOwnerTopUpListParam param) {
        IPage<OwnerTopUpVO> page = ownerTopUpService.ownerTopUpPageList(param);
        return Result.page(page.getRecords(), page.getTotal(), page.getPages());
    }

    @ApiOperation(value = "货主提现记录列表", notes = "<br>By:胡宇帆")
    @PostMapping("/ownerCaseOutPageList")
    @UnitCovert(param = false)
    public Result<PageData<OwnerCaseOutVO>> ownerCaseOutPageList(@RequestBody PageOwnerCaseOutListParam param) {
        IPage<OwnerCaseOutVO> page = ownerCaseOutService.ownerCaseOutPageList(param);
        return Result.page(page.getRecords(), page.getTotal(), page.getPages());
    }


    @ApiOperation(value = "账户充值", notes = "<br>By:胡宇帆")
    @PostMapping("/accountTopUp")
    @UnitCovert(param = false)
    public Result<Long> accountTopUp(@RequestBody OwnerTopUpParam param) {
        Long id = ownerAccountService.accountTopUp(param);
        return Result.ok(id);
    }

    @ApiOperation(value = "账户提现", notes = "<br>By:胡宇帆")
    @PostMapping("/accountCaseOut")
    @UnitCovert(param = false)
    public Result<Long> accountCaseOut(@RequestBody OwnerCaseOutParam param) {
        Long id = ownerAccountService.accountCaseOut(param);
        return Result.ok(id);
    }

    @ApiOperation(value = "货主账户流水列表", notes = "<br>By:胡宇帆")
    @PostMapping("/ownerAccountRunningWaterPageList")
    @UnitCovert(param = false)
    public Result<PageData<OwnerAccountRunningWaterRecordVO>> ownerAccountRunningWaterPageList(@RequestBody PageOwnerAccountRunningWaterParam param) {
        IPage<OwnerAccountRunningWaterRecordVO> page = ownerRunningWaterRecordService.ownerAccountRunningWaterPageList(param);
        return Result.page(page.getRecords(), page.getTotal(), page.getPages());
    }
}
